--------------------------------------------------------------------------------
-- CREATE TABLE
CREATE TABLE log_dxt_data (
    action                         VARCHAR2(1)
  , rec_date                       DATE
  , rec_user                       VARCHAR2(240)
  , data_id                        VARCHAR2(240)
  , data_cd                        VARCHAR2(480)
  , data_name                      VARCHAR2(240)
  , odbc_name                      VARCHAR2(240)
  , odbc_user                      VARCHAR2(240)
  , sql_text                       CLOB
  , page_size                      NUMBER
  , comments                       VARCHAR2(2000)
);

COMMENT ON TABLE  log_dxt_data IS 'f[^(LOG)';
COMMENT ON COLUMN log_dxt_data.action                         IS 'ANV';
COMMENT ON COLUMN log_dxt_data.rec_date                       IS 'XV';
COMMENT ON COLUMN log_dxt_data.rec_user                       IS 'XV';
COMMENT ON COLUMN log_dxt_data.data_id                        IS 'f[^ID';
COMMENT ON COLUMN log_dxt_data.data_cd                        IS 'f[^R[h';
COMMENT ON COLUMN log_dxt_data.data_name                      IS 'f[^';
COMMENT ON COLUMN log_dxt_data.odbc_name                      IS 'ODBC';
COMMENT ON COLUMN log_dxt_data.odbc_user                      IS 'ODBC[U[';
COMMENT ON COLUMN log_dxt_data.sql_text                       IS 'SQL';
COMMENT ON COLUMN log_dxt_data.page_size                      IS 'f[^TCY';
COMMENT ON COLUMN log_dxt_data.comments                       IS 'Rg';

--------------------------------------------------------------------------------
-- CREATE TRIGGER
CREATE OR REPLACE TRIGGER log_dxt_data
AFTER INSERT OR DELETE OR UPDATE ON dxt_data
FOR EACH ROW
DECLARE
    rec_log log_dxt_data %ROWTYPE;
BEGIN
    --
    rec_log := NULL;
    --
    IF INSERTING THEN
        rec_log.action := 'I';
    ELSIF UPDATING THEN
        rec_log.action := 'U';
    ELSIF DELETING THEN
        rec_log.action := 'D';
    END IF;
    --
    IF INSERTING OR UPDATING THEN
        rec_log.rec_date  := :NEW.rec_date  ;
        rec_log.rec_user  := :NEW.rec_user  ;
        rec_log.data_id   := :NEW.data_id   ;
        rec_log.data_cd   := :NEW.data_cd   ;
        rec_log.data_name := :NEW.data_name ;
        rec_log.odbc_name := :NEW.odbc_name ;
        rec_log.odbc_user := :NEW.odbc_user ;
        rec_log.sql_text  := :NEW.sql_text  ;
        rec_log.page_size := :NEW.page_size ;
        rec_log.comments  := :NEW.comments  ;
    ELSE
        rec_log.rec_date  := SYSDATE        ;
        rec_log.rec_user  := :OLD.rec_user  ;
        rec_log.data_id   := :OLD.data_id   ;
        rec_log.data_cd   := :OLD.data_cd   ;
        rec_log.data_name := :OLD.data_name ;
        rec_log.odbc_name := :OLD.odbc_name ;
        rec_log.odbc_user := :OLD.odbc_user ;
        rec_log.sql_text  := :OLD.sql_text  ;
        rec_log.page_size := :OLD.page_size ;
        rec_log.comments  := :OLD.comments  ;
    END IF;
    --
    INSERT INTO log_dxt_data VALUES rec_log;
    --
END;
/
